@@ -12,7 +12,8 @@ environ_more_defaults = {
 
 
 def start_response(*a, **kw):
-    pass
+    http_status = a[0]
+    print 'wsgipreload pid=%s: response code %s' % (pid, http_status)
 
 
 def request(app, url, extra_environ):
